@@ -7,7 +7,7 @@ package Lemonldap::NG::Portal::AuthMulti;
 
 use Lemonldap::NG::Portal::_Multi;    #inherits
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.6';
 
 sub authInit {
     my $self = shift;
@@ -36,6 +36,11 @@ sub authFinish {
     return $self->_multi->try( 'authFinish', 0 );
 }
 
+sub authPostStore {
+    my $self = shift;
+    return $self->_multi->try( 'authPostStore', 0 );
+}
+
 sub authLogout {
     my $self = shift;
     return $self->_multi->try( 'authLogout', 0 );
@@ -44,13 +49,14 @@ sub authLogout {
 sub authForce {
     my $self = shift;
     $self->_sub('authInit');
-    my $s    = $self->{_multi}->{last}->[0] . "::authForce";
+    my $s = $self->{_multi}->{last}->[0] . "::authForce";
     return &{$s}($self);
 }
 
 sub getDisplayType {
     my $self = shift;
-    my $s    = $self->{_multi}->{last}->[0] . "::getDisplayType";
+    return unless defined $self->{_multi}->{last};
+    my $s = $self->{_multi}->{last}->[0] . "::getDisplayType";
     return &{$s};
 }
 
