@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;
 our @ISA = qw(Lemonldap::NG::Portal::_SAML);
 
-our $VERSION = '1.9.9';
+our $VERSION = '1.9.13';
 
 ## @method void issuerDBInit()
 # Load and check SAML configuration
@@ -32,6 +32,38 @@ sub issuerDBInit {
     PE_OK;
 }
 
+## @apmethod string normalize_url()
+# Normalize url to be tolerant to SAML Path
+# Usefull if SAML Path is a regex
+# @return normalized url
+sub normalize_url {
+    my ( $self, $url, $samlPath, $metadataUrl ) = @_;
+
+    my $initialPath = "";
+    my $finalPath   = "";
+
+    # Get current (bad) path
+    if ( $url =~ m~($samlPath)~ ) {
+        $initialPath = $1;
+    }
+
+    # Get destination (good) path
+    if ( $metadataUrl =~ m~($samlPath)~ ) {
+        $finalPath = $1;
+    }
+
+    if (    $initialPath ne ""
+        and $finalPath ne ""
+        and $initialPath ne $finalPath )
+    {
+        $self->lmLog( "Normalizing url path form $initialPath to $finalPath",
+            'info' );
+        $url =~ s~$initialPath~$finalPath~;
+    }
+
+    return $url;
+}
+
 ## @apmethod int issuerForUnAuthUser()
 # Check if there is an SAML authentication request
 # Called only for unauthenticated users, check isPassive flag
@@ -90,6 +122,11 @@ sub issuerForUnAuthUser {
     my $idp_initiated_sp        = $self->param('sp');
     my $idp_initiated_spConfKey = $self->param('spConfKey');
 
+    # Normalize URL to be tolerant to SAML Path
+    $url =
+      $self->normalize_url( $url, $self->{issuerDBSAMLPath},
+        $saml_sso_get_url );
+
     # 1.1. SSO
     if ( $url =~
 /^(\Q$saml_sso_soap_url\E|\Q$saml_sso_soap_url_ret\E|\Q$saml_sso_get_url\E|\Q$saml_sso_get_url_ret\E|\Q$saml_sso_post_url\E|\Q$saml_sso_post_url_ret\E|\Q$saml_sso_art_url\E|\Q$saml_sso_art_url_ret\E)$/io
@@ -1172,6 +1209,11 @@ sub issuerForAuthUser {
     my $idp_initiated_sp        = $self->param('sp');
     my $idp_initiated_spConfKey = $self->param('spConfKey');
 
+    # Normalize URL to be tolerant to SAML Path
+    $url =
+      $self->normalize_url( $url, $self->{issuerDBSAMLPath},
+        $saml_sso_get_url );
+
     # 1.1. SSO (SSO URL or Proxy Mode)
     if ( $url =~
 /^(\Q$saml_sso_soap_url\E|\Q$saml_sso_soap_url_ret\E|\Q$saml_sso_get_url\E|\Q$saml_sso_get_url_ret\E|\Q$saml_sso_post_url\E|\Q$saml_sso_post_url_ret\E|\Q$saml_sso_art_url\E|\Q$saml_sso_art_url_ret\E)$/io
