@@ -16,7 +16,7 @@ use URI::Split qw(uri_split);
 *EXPORT_TAGS = *Lemonldap::NG::Portal::Simple::EXPORT_TAGS;
 *EXPORT      = *Lemonldap::NG::Portal::Simple::EXPORT;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.9';
 use base qw(Lemonldap::NG::Portal::Simple);
 our $confCached;
 
@@ -89,6 +89,7 @@ sub getConf {
             $re->add($quotedVhost);
 
             # Add aliases
+            $confCached->{vhostOptions}->{$vhost} ||= {};
             if ( $confCached->{vhostOptions}->{$vhost}->{vhostAliases} ) {
                 foreach my $alias ( split /\s+/,
                     $confCached->{vhostOptions}->{$vhost}->{vhostAliases} )
@@ -164,7 +165,7 @@ compatible portals using a central configuration database.
   else {
     # Write here the html form used to authenticate with CGI methods.
     # $portal->error returns the error message if athentification failed
-    # Warning: by defaut, input names are "user" and "password"
+    # Warning: by default, input names are "user" and "password"
     print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see L<CGI(3)>)
     print "...";
     print '<form method="POST">';
